"""
xray_pipeline
=============

Modular pipeline for extracting, stacking and fitting X-ray spectra
from Chandra, Swift-XRT and XMM-Newton.
"""
__all__ = ["chandra", "swiftxrt", "xmm", "nustar"]
__version__ = "0.2.2"